==> haskell-tasty-silver-3.3.2-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2
visibility:           public
id:                   tasty-silver-3.3.2-DA4aoxVX36m1eMKfitPQuv
key:                  tasty-silver-3.3.2-DA4aoxVX36m1eMKfitPQuv
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  cb027f858a4a84b301023eadcf08c116
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2-DA4aoxVX36m1eMKfitPQuv
depends:
    ansi-terminal-1.0.2-HptUcAgyCR58cokR0SMdxn
    async-2.2.5-HMp4lCE5MFwDsdQT9P7pHP base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-6krVryETStC73hI3cDgd1Y
    process-1.6.18.0 process-extras-0.7.4-JgH59wP6fNrGDKy65hFSbC
    regex-tdfa-1.3.2.4-4v18KqMgCkG8zIhzTwZAyQ
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-2VF3Rdd37bz4PqVnWDagdL
    temporary-1.3-3mtZbkJPoBb5nlmfkfYt6T text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-silver-3.3.2-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-silver
version:              3.3.2
visibility:           public
id:                   tasty-silver-3.3.2-4ye6JiCyizC3dNw3hyAasT
key:                  tasty-silver-3.3.2-4ye6JiCyizC3dNw3hyAasT
license:              MIT
maintainer:           Andreas Abel, Philipp Hausmann
author:               Philipp Hausmann, Andreas Abel, Roman Cheplyaka, and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  7fb3bf28be7a5ddf8aba382fa696da83
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-silver-3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.2-4ye6JiCyizC3dNw3hyAasT
depends:
    ansi-terminal-1.0.2-FdTURvxQW9QL5jnf7uGcXG
    async-2.2.5-1z0oB69LG2FBRno1il1zoZ base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    optparse-applicative-0.18.1.0-Ebh0I8Iojv3DBRdzITzz2E
    process-1.6.18.0 process-extras-0.7.4-GFn42TCFCPGCONKIzXKbDP
    regex-tdfa-1.3.2.4-En3QX8Ja5Gq8UtJhpcCkzY
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-1LVG3MTEaeV50BoWi4FIMR
    temporary-1.3-G3JGTlFyfueEWhF9il8L2k text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
